@@ -9,15 +9,17 @@ This module provides the CLI interface to legit.
 import os
 
 import click
+import crayons
 from clint import resources
 from clint.textui import columns
-import crayons
 
 from .core import __version__
 from .scm import SCMRepo
 from .settings import legit_settings
-from .utils import black, format_help, order_manually, output_aliases, status_log, verbose_echo
-
+from .utils import (
+    black, format_help, git_version, order_manually, output_aliases,
+    status_log, verbose_echo, program_path
+)
 
 CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 pass_scm = click.make_pass_decorator(SCMRepo)
@@ -121,7 +123,7 @@ def switch(scm, to_branch, verbose, fake):
         raise click.BadArgumentUsage('Please specify a branch to switch to')
 
     scm.stash_log()
-    status_log(scm.checkout_branch, 'Switching to {0}.'.format(
+    status_log(scm.checkout_branch, 'Switching to {}.'.format(
         crayons.yellow(to_branch)), to_branch)
     scm.unstash_log()
 
@@ -151,7 +153,7 @@ def sync(ctx, scm, to_branch, verbose, fake):
             original_branch = scm.get_current_branch_name()
         else:
             raise click.BadArgumentUsage(
-                "Branch {0} does not exist. Use an existing branch."
+                "Branch {} does not exist. Use an existing branch."
                 .format(crayons.yellow(branch)))
     else:
         # Sync current branch.
@@ -169,7 +171,7 @@ def sync(ctx, scm, to_branch, verbose, fake):
             ctx.invoke(switch, to_branch=original_branch, verbose=verbose, fake=fake)
     else:
         raise click.BadArgumentUsage(
-            "Branch {0} is not published. Publish before syncing."
+            "Branch {} is not published. Publish before syncing."
             .format(crayons.yellow(branch)))
 
 
@@ -190,20 +192,20 @@ def publish(scm, to_branch, verbose, fake):
         branch = scm.get_current_branch_name()
         scm.display_available_branches()
         if to_branch is None:
-            click.echo("Using current branch {0}".format(crayons.yellow(branch)))
+            click.echo("Using current branch {}".format(crayons.yellow(branch)))
         else:
             click.echo(
-                "Branch {0} not found, using current branch {1}"
+                "Branch {} not found, using current branch {}"
                 .format(crayons.red(to_branch), crayons.yellow(branch)))
 
     branch_names = scm.get_branch_names(local=False)
 
     if branch in branch_names:
         raise click.BadArgumentUsage(
-            "Branch {0} is already published. Use a branch that is not published."
+            "Branch {} is already published. Use a branch that is not published."
             .format(crayons.yellow(branch)))
 
-    status_log(scm.publish_branch, 'Publishing {0}.'.format(
+    status_log(scm.publish_branch, 'Publishing {}.'.format(
         crayons.yellow(branch)), branch)
 
 
@@ -228,10 +230,10 @@ def unpublish(scm, published_branch, verbose, fake):
 
     if branch not in branch_names:
         raise click.BadArgumentUsage(
-            "Branch {0} is not published. Use a branch that is published."
+            "Branch {} is not published. Use a branch that is published."
             .format(crayons.yellow(branch)))
 
-    status_log(scm.unpublish_branch, 'Unpublishing {0}.'.format(
+    status_log(scm.unpublish_branch, 'Unpublishing {}.'.format(
         crayons.yellow(branch)), branch)
 
 
@@ -251,24 +253,35 @@ def undo(scm, verbose, fake, hard):
 
 
 @cli.command()
+@click.argument('wildcard_pattern', required=False)
 @pass_scm
-def branches(scm):
+def branches(scm, wildcard_pattern):
     """Displays a list of branches."""
     scm.repo_check()
 
-    scm.display_available_branches()
+    if wildcard_pattern:
+        scm.display_available_branches(wildcard_pattern)
+    else:
+        scm.display_available_branches()
 
 
 def do_install(ctx, verbose, fake):
     """Installs legit git aliases."""
     click.echo('The following git aliases will be installed:\n')
     aliases = cli.list_commands(ctx)
+    if git_version() >= (2, 23, 0):
+        click.echo(
+            'As git 2.23.0 introduces a new command "git switch", alias "switch"'
+            ' will be skipped.\nUse "legit switch" instead.'
+        )
+        aliases.remove('switch')
     output_aliases(aliases)
 
+    program = program_path()
     if click.confirm('\n{}Install aliases above?'.format('FAKE ' if fake else ''), default=fake):
         for alias in aliases:
-            cmd = '!legit ' + alias
-            system_command = 'git config --global --replace-all alias.{0} "{1}"'.format(alias, cmd)
+            cmd = '!{} {}'.format(program, alias)
+            system_command = 'git config --global --replace-all alias.{} "{}"'.format(alias, cmd)
             verbose_echo(system_command, verbose, fake)
             if not fake:
                 os.system(system_command)
@@ -284,7 +297,7 @@ def do_uninstall(ctx, verbose, fake):
     # Add deprecated aliases
     aliases.extend(['graft', 'harvest', 'sprout', 'resync', 'settings', 'install', 'uninstall'])
     for alias in aliases:
-        system_command = 'git config --global --unset-all alias.{0}'.format(alias)
+        system_command = 'git config --global --unset-all alias.{}'.format(alias)
         verbose_echo(system_command, verbose, fake)
         if not fake:
             os.system(system_command)
@@ -307,11 +320,11 @@ def do_edit_settings(fake):
     if fake:
         click.echo(crayons.red('Faked! >>> edit {}'.format(path)))
     else:
-        click.edit(path)
+        click.edit(filename=path)
 
 
 def handle_abort(aborted, type=None):
-    click.echo('{0} {1}'.format(crayons.red('Error:'), aborted.message))
+    click.echo('{} {}'.format(crayons.red('Error:'), aborted.message))
     click.echo(str(aborted.log))
     if type == 'merge':
         click.echo('Unfortunately, there was a merge conflict.'
