@@ -8,8 +8,9 @@ This module provides the basic functionality of legit.
 """
 
 from . import bootstrap
+
 del bootstrap
 
-__version__ = '1.0.0'
-__author__ = 'Kenneth Reitz'
-__license__ = 'BSD'
+__version__ = "1.2.0post0"
+__author__ = "Kenneth Reitz"
+__license__ = "BSD"
